==> haskell-monad-logger-0.3.42-81-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW
key:                  monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  c87d55de93c111d60f193972db248939
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j exceptions-0.10.5
    fast-logger-3.2.4-GrQ8nFhR5mpA8EuxDsGHQ2
    lifted-base-0.2.3.12-HR3njwBKkQfIczM7PCgcTP
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.42-100-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG
key:                  monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  3ee4e68f290312bd28fdba216d3dcc75
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P exceptions-0.10.5
    fast-logger-3.2.4-CmUTOIzlIrP2oPyQXhvG8f
    lifted-base-0.2.3.12-BlE7lcjJgycKqbOSX0EJAx
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
